@@ -3,7 +3,7 @@
 #' A \code{\link{cv}()} method for an object of class  \code{"modlist"},
 #' created by the \code{models()} function. This \code{cv()} method simplifies
 #' the process of cross-validating several models on the same set of CV folds
-#' and may also be used for recursive CV, where CV is used to select one from among
+#' and may also be used for meta CV, where CV is used to select one from among
 #' several models. \code{models()} performs some
 #' "sanity" checks, warning if the models are of different classes, and
 #' reporting an error if they are fit to apparently different data sets or
@@ -21,7 +21,7 @@
 #' to be used to create the same set of CV folds for all of the models;
 #' if omitted, a seed will be randomly generated and saved. Not used for
 #' leave-one-out CV.
-#' @param recursive if \code{TRUE} (the default is \code{FALSE}), cross-validation
+#' @param meta if \code{TRUE} (the default is \code{FALSE}), cross-validation
 #' is performed recursively to select a "best" model deleting each fold in turn
 #' by calculating the CV estimate of the criterion for the remaining folds;
 #' this is equivalent to employing the \code{\link{selectModelList}()} model-selection
@@ -65,12 +65,15 @@
 #' @param col color for the line and points, defaults to the second
 #' element of the color palette; see \code{\link{palette}()}.
 #' @param lwd line width for the line (defaults to 2).
+#' @param object an object to summarize.
 #' @return \code{models()} returns a \code{"modList"} object, the
 #' \code{cv()} method for which returns a \code{"cvModList"} object,
-#' or, when \code{recursive=TRUE}, an object of class \code{c("cvSelect", "cv")}.
+#' or, when \code{meta=TRUE}, an object of class \code{c("cvSelect", "cv")}.
 #' @seealso \code{\link{cv}}, \code{\link{cv.merMod}},
 #' \code{\link{selectModelList}}.
 #' @examples
+#' if (requireNamespace("carData", quietly=TRUE)){
+#' withAutoprint({
 #' data("Duncan", package="carData")
 #' m1 <- lm(prestige ~ income + education, data=Duncan)
 #' m2 <- lm(prestige ~ income + education + type, data=Duncan)
@@ -85,10 +88,14 @@
 #'                     data=Duncan, seed=5963, confint=TRUE, level=0.50))
 #'                  # nb: n too small for accurate CIs
 #' plot(cv.models.ci)
-#' (cv.models.recursive <- cv(models(m1=m1, m2=m2, m3=m3),
-#'                            data=Duncan, seed=5963,
-#'                            recursive=TRUE, save.model=TRUE))
-#' cv.models.recursive$selected.model
+#' (cv.models.meta <- cv(models(m1=m1, m2=m2, m3=m3),
+#'                       data=Duncan, seed=5963,
+#'                       meta=TRUE, save.model=TRUE))
+#' cvInfo(cv.models.meta, "selected model")
+#' })
+#' } else {
+#' cat("install the 'carData' package to run these examples\n")
+#' }
 
 #' @describeIn cv.modList \code{cv()} method for \code{"modList"} objects.
 #' @exportS3Method
@@ -100,13 +107,13 @@ cv.modList <-
            reps = 1L,
            seed,
            quietly = TRUE,
-           recursive = FALSE,
+           meta = FALSE,
            ...) {
     if (missing(seed) && !(k == "loo" || k == "n")) {
       seed <- sample(1e6, 1L)
       message("R RNG seed set to ", seed)
     }
-    if (recursive) {
+    if (meta) {
       if (missing(k))
         k <- 10L
       if (k == "loo" || k == "n")
@@ -223,23 +230,49 @@ print.cvModList <- function(x, ...) {
   if (inherits(x[[1L]], "cvList")) {
     reps <- length(x[[1L]])
     nms <-
-      paste0(nms, " averaged across ", reps, " replications (with SDs)")
+      paste0(nms, " averaged across ", reps, " replications")
   }
   for (i in seq_along(x)) {
-    cat(paste0("\nModel ", nms[i], ":\n"))
+    cat(paste0("Model ", nms[i], ":\n"))
     if (inherits(x[[i]], "cvList")) {
       sumry <- summarizeReps(x[[i]])
       xi <- x[[i]][[1L]]
       nms.sumry <- names(sumry)
       xi[nms.sumry] <- sumry
       print(xi)
+      cat("\n")
     } else {
       print(x[[i]], ...)
+      cat("\n")
     }
   }
   return(invisible(x))
 }
 
+#' @describeIn cv.modList \code{summary()} method for \code{"cvModList"} objects.
+#' @exportS3Method
+summary.cvModList <- function(object, ...) {
+  nms <- names(object)
+  if (inherits(object[[1L]], "cvList")) {
+    reps <- length(object[[1L]])
+    nms <-
+      paste0(nms, " averaged across ", reps, " replications (with SDs)")
+  }
+  for (i in seq_along(object)) {
+    cat(paste0("\nModel ", nms[i], ":\n"))
+    if (inherits(object[[i]], "cvList")) {
+      sumry <- summarizeReps(object[[i]])
+      xi <- object[[i]][[1L]]
+      nms.sumry <- names(sumry)
+      xi[nms.sumry] <- sumry
+      summary(xi)
+    } else {
+      summary(object[[i]], ...)
+    }
+  }
+  return(invisible(object))
+}
+
 #' @describeIn cv.modList \code{plot()} method for \code{"cvModList"} objects.
 #' @importFrom grDevices palette
 #' @importFrom graphics abline arrows axis box par points strwidth
