@@ -118,7 +118,7 @@ test_that("cvSelect parallel selectTransStepAIC", {
   )
 })
 
-# test recursive CV
+# test meta CV
 
 data("Auto", package="ISLR2")
 for (p in 1:10){
@@ -127,19 +127,19 @@ for (p in 1:10){
   eval(parse(text=command))
 }
 
-cv1 <- cv(selectModelList, Auto, k=10, k.recurse="loo",
+cv1 <- cv(selectModelList, Auto, k=10, k.meta="loo",
           working.model=models(m.1, m.2, m.3, m.4, m.5,
                                m.6, m.7, m.8, m.9, m.10),
           save.model=TRUE,
           seed=123)
 cv2 <- cv(models(m.1, m.2, m.3, m.4, m.5,
                  m.6, m.7, m.8, m.9, m.10),
-          recursive=TRUE,
-          k=10, k.recurse="loo",
+          meta=TRUE,
+          k=10, k.meta="loo",
           save.model=TRUE,
           seed=123)
 cv1$criterion <- cv2$criterion <- NULL
-test_that("cv(SelectModelList()) and cv.modList() produce same recursive CV/k-LOO", {
+test_that("cv(SelectModelList()) and cv.modList() produce same meta CV/k-LOO", {
   expect_equal(cv1, cv2)
 })
 
@@ -150,15 +150,15 @@ cv1 <- cv(selectModelList, Auto,
           seed=123)
 cv2 <- cv(models(m.1, m.2, m.3, m.4, m.5,
                  m.6, m.7, m.8, m.9, m.10),
-          recursive=TRUE,
+          meta=TRUE,
           save.model=TRUE,
           seed=123)
 cv1$criterion <- cv2$criterion <- NULL
-test_that("cv(SelectModelList()) and cv.modList() produce same recursive CV/k-fold", {
+test_that("cv(SelectModelList()) and cv.modList() produce same meta CV/k-fold", {
   expect_equal(cv1, cv2)
 })
 
-test_that("recursive SelectModelList() works with parallel computation loo", {
+test_that("meta SelectModelList() works with parallel computation loo", {
   expect_equal(
     cv(selectModelList, Auto, k="loo",
        working.model=models(m.1, m.2, m.3, m.4, m.5,
@@ -172,7 +172,7 @@ test_that("recursive SelectModelList() works with parallel computation loo", {
   )
 })
 
-test_that("recursive SelectModelList() works with parallel computation k-fold", {
+test_that("meta SelectModelList() works with parallel computation k-fold", {
   expect_equal(
     cv(selectModelList, Auto,
        working.model=models(m.1, m.2, m.3, m.4, m.5,
